﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Syncfusion.UI.Xaml.Grid;
using Syncfusion.UI.Xaml.Grid.Helpers;
using System.Collections.ObjectModel;
using Syncfusion.UI.Xaml.ScrollAxis;

namespace SfDataGridDemo
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {

        ObservableCollection<UserInfo> view = null;
        public MainWindow()
        {
            InitializeComponent();
            // based on windows size the SfDataGrid size will be varied
            this.sfGrid.SizeChanged += SfGrid_SizeChanged;            
        }
        
        double sfGridheight, rowHeight = 0.0;
        int addNewRowControllerIndex, unBoundRows = 0;
        private void SfGrid_SizeChanged(object sender, SizeChangedEventArgs e)
        {
            view = (this.sfGrid.DataContext as UserInfoViewModel).UserDetails;

            // based on windows size the SfDataGrid size is mearsured
            sfGridheight = e.NewSize.Height;

            // rowheight of dataRow, HeaderRow and addNewRow height are calculated
            rowHeight = GetDataGridRowHeight();

            #region AddNewRow

            // to check dataGrid contains AddNewRow or not
            addNewRowControllerIndex = this.sfGrid.GetAddNewRowController().GetAddNewRowIndex();
            bool isAddNewRowIndex = this.sfGrid.IsAddNewIndex(addNewRowControllerIndex);

            if (isAddNewRowIndex)
                addNewRowControllerIndex = 1;
            else
                addNewRowControllerIndex = 0;

            #endregion          

            // based on window size changed the empty row are added/removed in dataGrid
            AddRemoveUnBoundRow();

            // when the collection are changed (adding or removing records), that time CollectionChanged event are triggered.
            this.sfGrid.View.CollectionChanged += View_CollectionChanged;
        }
        private void View_CollectionChanged(object sender, System.Collections.Specialized.NotifyCollectionChangedEventArgs e)
        {
            // rowheight of dataRow, HeaderRow and addNewRow height are calculated
            rowHeight = GetDataGridRowHeight();
            // based on window size changed the empty row are added/removed in dataGrid
            AddRemoveUnBoundRow();
        }
        private double GetDataGridRowHeight()
        {
            // to removed the empty row in dataGrid
            foreach (var unbou in this.sfGrid.UnBoundRows.ToList())
            {
                this.sfGrid.UnBoundRows.Remove(unbou);
            }

            double dataRowHeight = 0.0;

            // based on row height of data row is calculated
            for (int i = 0; i < this.sfGrid.View.Records.Count; i++)
            {
                var visualContainer = this.sfGrid.GetVisualContainer();
                dataRowHeight += visualContainer.RowHeights[i + 1];
            }

            // rowheight of dataRow, HeaderRow and addNewRow height are calculated
            rowHeight = this.sfGrid.HeaderRowHeight + dataRowHeight + (addNewRowControllerIndex * 24);
            return rowHeight;
        }
        private void AddRemoveUnBoundRow()
        {
            int numberofRows = 0;
            if (rowHeight > sfGridheight)
            {
                // based on view records and empty space in dataGrid, the number of empty rows will be calculated
                numberofRows = (int)((rowHeight - sfGridheight) / this.sfGrid.RowHeight);
                if (numberofRows == 0)
                    numberofRows = 1;
                else
                    numberofRows += 1;

                for (int i = 0; i < numberofRows && unBoundRows > 0; i++)
                {
                    // to remove the empty row for dataGrid
                    this.sfGrid.UnBoundRows.RemoveAt(i);
                }
            }
            else
            {
                numberofRows = (int)((sfGridheight - rowHeight) / this.sfGrid.RowHeight);

                if (numberofRows > 0)
                {
                    for (int i = view.Count+1; i < (view.Count + numberofRows); i++)
                    {
                        // to add the empty row for dataGrid
                        this.sfGrid.UnBoundRows.Add(new GridUnBoundRow() { Position = UnBoundRowsPosition.Bottom });
                    }
                }
            }
        }
        private void Button_Click(object sender, RoutedEventArgs e)
        {
            for (int i = 0; i < 5; i++)
            {
                view.Add(new UserInfo() { UserId = i, Salary = 21111, Name="Sam"+i });
            }
        }
    }
}
